==> kaffe-0.8.0.tgz: kaffe-0.8.0/kaffe/kaffevm/gtypes.h <==
/*
 * gtypes.h
 * General types.
 *
 * Copyright (c) 1996 T. J. Wilkinson & Associates, London, UK.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * Written by Tim Wilkinson <tim@tjwassoc.demon.co.uk>, 1996.
 */

#ifndef __gtype_h
#define __gtype_h

#include "config.h"

#ifdef __CHAR_UNSIGNED__
#ifdef __STDC__
typedef signed char		int8;
#else
#error "no signed char type"
#endif
#else
typedef	char			int8;
#endif

typedef	unsigned char		uint8;

#if SIZEOF_SHORT == 2
typedef	short			int16;
typedef	unsigned short		uint16;
#else
#error "sizeof(short) must be 2"
#endif

#if SIZEOF_INT == 4
typedef	int			int32;
typedef	unsigned int		uint32;
#elif SIZEOF_LONG == 4
typedef	long			int32;
typedef	unsigned long		uint32;
#else
#error "sizeof(int) or sizeof(long) must be 4"
#endif

#if SIZEOF_LONG == 8
typedef long			int64;
typedef unsigned long		uint64;
#elif SIZEOF_LONG_LONG == 8
typedef	long long		int64;
typedef	unsigned long long	uint64;
#elif SIZEOF___INT64 == 8
typedef	__int64			int64;
typedef	unsigned __int64	uint64;
#endif

#if SIZEOF_VOIDP == 4
typedef uint32			uintp;
#elif SIZEOF_VOIDP == 8
typedef uint64			uintp;
#else
#error "sizeof(void*) must be 4 or 8"
#endif

typedef enum _bool {
	false	= 0,
	true	= 1,
} bool;

typedef uint16			jchar;
typedef int8			jbyte;
typedef int16                   jshort;
typedef int32                   jint;
typedef int64                   jlong;
typedef void*                   jref;
typedef float                   jfloat;
typedef double                  jdouble;

/* An integer type big enough for a pointer or a 32-bit int/float. */
#if SIZEOF_VOIDP == 4
typedef int32			jword;
#elif SIZEOF_VOIDP == 8
typedef int64			jword;
#else
#error "sizeof(void*) must be 4 or 8"
#endif

typedef uint8			u1;
typedef uint16			u2;
typedef uint32			u4;

typedef	u1		nativecode;
typedef u2		accessFlags;
typedef u2		constIndex;

typedef struct _strconst Utf8Const;
typedef struct _classes Class;
typedef struct _methods Method;
typedef struct _object Object;
#ifndef object
#define object struct _object
#endif
typedef struct _fields Field;
#ifndef stringClass
#define stringClass struct _stringClass
#endif

#define PTR_TYPE_SIZE sizeof(void*)

struct _constants;
struct _methodTable;
struct _dispatchTable;
struct _jexception;

/* If INTERN_UTF8CONSTS is 1, then all Utf8Const objects are interned in
 * a hashtable, thus you can compare them with ==.
 */
#define INTERN_UTF8CONSTS 1

struct _strconst {
#if !INTERN_UTF8CONSTS
	/* If we're not interning, store hash for fast comparisons. */
	uint16			hash;
#endif
	uint16			length;
	char			data[1]; /* In Utf8 format, with final '\0'. */
};

#define	SHIFT_jchar		1
#define	SHIFT_jbyte		0
#define	SHIFT_jshort		1
#define	SHIFT_jint		2
#define	SHIFT_jlong		3
#define	SHIFT_jfloat		2
#define	SHIFT_jdouble		3
#if SIZEOF_VOIDP == 4
#define	SHIFT_jref		2
#elif SIZEOF_VOIDP == 8
#define	SHIFT_jref		3
#endif

#endif

==> kaffe-0.8.1.tgz: kaffe-0.8.1/kaffe/kaffevm/gtypes.h <==
/*
 * gtypes.h
 * General types.
 *
 * Copyright (c) 1996 T. J. Wilkinson & Associates, London, UK.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * Written by Tim Wilkinson <tim@tjwassoc.demon.co.uk>, 1996.
 */

#ifndef __gtype_h
#define __gtype_h

#include "config.h"
#include "jtypes.h"

#ifdef __CHAR_UNSIGNED__
#ifdef __STDC__
typedef signed char		int8;
#else
#error "no signed char type"
#endif
#else
typedef	char			int8;
#endif

typedef	unsigned char		uint8;

#if SIZEOF_SHORT == 2
typedef	short			int16;
typedef	unsigned short		uint16;
#else
#error "sizeof(short) must be 2"
#endif

#if SIZEOF_INT == 4
typedef	int			int32;
typedef	unsigned int		uint32;
#elif SIZEOF_LONG == 4
typedef	long			int32;
typedef	unsigned long		uint32;
#else
#error "sizeof(int) or sizeof(long) must be 4"
#endif

#if SIZEOF_LONG_LONG == 8
typedef	long long		int64;
typedef	unsigned long long	uint64;
#elif SIZEOF___INT64 == 8
typedef	__int64			int64;
typedef	unsigned __int64	uint64;
#else
#error "sizeof(long long) or sizeof(__int64) must be 8"
#endif

#if SIZEOF_VOIDP == 4
typedef uint32			uintp;
#elif SIZEOF_VOIDP == 8
typedef uint64			uintp;
#else
#error "sizeof(void*) must be 4 or 8"
#endif

typedef enum _bool {
	false	= 0,
	true	= 1,
} bool;

typedef uint8			u1;
typedef uint16			u2;
typedef uint32			u4;

typedef	u1		nativecode;
typedef u2		accessFlags;
typedef u2		constIndex;

typedef struct _strconst Utf8Const;
typedef struct _classes Class;
typedef struct _methods Method;
#ifndef Object
#define Object struct _object
#endif
typedef struct _fields Field;
#ifndef stringClass
#define stringClass struct _stringClass
#endif

#define PTR_TYPE_SIZE SIZEOF_VOIDP

struct _constants;
struct _methodTable;
struct _dispatchTable;
struct _jexception;

/* If INTERN_UTF8CONSTS is 1, then all Utf8Const objects are interned in
 * a hashtable, thus you can compare them with ==.
 */
#define INTERN_UTF8CONSTS 1

struct _strconst {
#if !INTERN_UTF8CONSTS
	/* If we're not interning, store hash for fast comparisons. */
	uint16			hash;
#endif
	uint16			length;
	char			data[1]; /* In Utf8 format, with final '\0'. */
};

#define	SHIFT_jchar		1
#define	SHIFT_jbyte		0
#define	SHIFT_jshort		1
#define	SHIFT_jint		2
#define	SHIFT_jlong		3
#define	SHIFT_jfloat		2
#define	SHIFT_jdouble		3
#if SIZEOF_VOIDP == 4
#define	SHIFT_jref		2
#elif SIZEOF_VOIDP == 8
#define	SHIFT_jref		3
#endif

#endif
